import dataclasses
import heapq
import sys
import typing
import queue


def input():
    return sys.stdin.readline()[:-1]


@dataclasses.dataclass
class Edge:
    u: int
    v: int
    t: int


def find_ans(n: int, e: typing.List[Edge]) -> int:
    entrance = 0
    orthanc = n - 1
    MAX_WEIGHT = 1_000_000

    # Dijkstra algorithm in m log n
    INF = n * MAX_WEIGHT
    ingoing_arcs = [[] for _ in range(n)]
    for arc in e:
        if arc.u == orthanc:
            continue
        ingoing_arcs[arc.v].append(arc)
    distance_to_orthanc = [INF for _ in range(n)]
    nearest = [(0, orthanc)]
    distance_to_orthanc[orthanc] = 0
    while nearest:
        current_distance_to_orthanc, current_tower = heapq.heappop(nearest)
        if current_distance_to_orthanc != distance_to_orthanc[current_tower]:
            continue
        for arc in ingoing_arcs[current_tower]:
            another_tower = arc.u
            new_distance_to_orthanc = current_distance_to_orthanc + arc.t
            if new_distance_to_orthanc < distance_to_orthanc[another_tower]:
                distance_to_orthanc[another_tower] = new_distance_to_orthanc
                heapq.heappush(nearest, (new_distance_to_orthanc, another_tower))

    # outgoing effective degree
    outgoing_effective_degree = [0 for _ in range(n)]
    for arc in e:
        if distance_to_orthanc[arc.u] == distance_to_orthanc[arc.v] + arc.t:
            outgoing_effective_degree[arc.u] += 1

    # bfs with occasional retro-analysis
    incompetence = [n for _ in range(n)]
    bfs_queue = queue.SimpleQueue()
    retro_queue = queue.SimpleQueue()
    for tower_index in range(n):
        if distance_to_orthanc[tower_index] == INF:
            incompetence[tower_index] = -1
            bfs_queue.put(tower_index)
    while not bfs_queue.empty() or not retro_queue.empty():
        if not bfs_queue.empty():
            current_tower = bfs_queue.get()
            new_incompetence = incompetence[current_tower] + 1
            for arc in ingoing_arcs[current_tower]:
                another_tower = arc.u
                if incompetence[another_tower] > new_incompetence:
                    incompetence[another_tower] = new_incompetence
                    retro_queue.put(another_tower)
        else:
            while not retro_queue.empty():
                current_tower = retro_queue.get()
                bfs_queue.put(current_tower)
                current_incompetence = incompetence[current_tower]
                for arc in ingoing_arcs[current_tower]:
                    another_tower = arc.u
                    induced_distance_to_orthanc = distance_to_orthanc[current_tower] + arc.t
                    if induced_distance_to_orthanc != distance_to_orthanc[another_tower]:
                        continue
                    if incompetence[another_tower] <= current_incompetence:
                        continue
                    outgoing_effective_degree[another_tower] -= 1
                    if outgoing_effective_degree[another_tower] > 0:
                        continue
                    incompetence[another_tower] = current_incompetence
                    retro_queue.put(another_tower)
    return incompetence[entrance]

def solve_test() -> None:
    n, m = map(int, input().split())
    e = []
    for _ in range(m):
        u, v, t = map(int, input().split())
        e.append(Edge(u - 1, v - 1, t))
    ans = find_ans(n, e)
    print(ans)


def main() -> None:
    solve_test()


if __name__ == "__main__":
    main()
