#include <iostream>
#include <vector>

using namespace std;

const char* Unique = "Unique";
const char* Multiple = "Multiple";
const char* None = "None";

struct Floor {
    int length{};
    vector<bool> is_damaged{};

    void repair_right(int i) {
        is_damaged[i + 1] = false;
    }

    void repair_down(int i) {
        is_damaged[i + length] = false;
    }

    bool is_right_damaged(int i) const {
        return is_damaged[i + 1];
    }

    bool is_down_damaged(int i) const {
        return is_damaged[i + length];
    }
};

const char* find_solution_for(Floor& floor) {
    int length = floor.length;
    bool is_unique = true;

    for (int i{0}; i < floor.length - 1; ++i) {
        if (floor.is_damaged[i]) {
            if (floor.is_down_damaged(i)) {
                floor.repair_down(i);
                if (floor.is_right_damaged(i) && floor.is_down_damaged(i + 1))
                    is_unique = false;
            }
            else if (floor.is_right_damaged(i)) {
                floor.repair_right(i);
            }
            else {
                return None;
            }
        }
        else if (floor.is_down_damaged(i)) {
            if (floor.is_right_damaged(i + length))
                floor.repair_right(i + length);
            else return None;
        }
    }

    bool up_damaged = floor.is_damaged[length - 1];
    bool down_damaged = floor.is_damaged[2 * length - 1];

    if (up_damaged != down_damaged)
        return None;

    return is_unique ? Unique : Multiple;
}

vector<Floor> read_input() {
    int num_tests;
    cin >> num_tests;

    vector<Floor> test(num_tests);
    for (int i{0}; i < num_tests; ++i) {
        int length;
        cin >> length;
        test[i].length = length;
        test[i].is_damaged.resize(2 * length);
        for (int j{0}; j < 2 * length; ++j) {
            char tile;
            cin >> tile;
            test[i].is_damaged[j] = (tile == '.');
        }
    }

    return test;
}

int main() {
    auto input = read_input();
    for (auto& floor : input) {
        cout << find_solution_for(floor) << endl;
    }
    return 0;
}
