#include <bits/stdc++.h>

using namespace std;

template<typename T1, typename T2>
pair<T1, T2>& operator +=(pair<T1, T2>& a, const pair<T1, T2>& b)
{
    a.first += b.first;
    a.second += b.second;
    return a;
}

template<typename T1, typename T2>
pair<T1, T2> operator +(const pair<T1, T2>& a, const pair<T1, T2>& b)
{
    return {a.first + b.first, a.second + b.second};
}

template<typename T1, typename T2>
pair<T1, T2> operator -(const pair<T1, T2>& a, const pair<T1, T2>& b)
{
    return {a.first - b.first, a.second - b.second};
}

typedef long long ll;

typedef pair <ll, ll> dig;
typedef pair <dig, dig> coord;
typedef pair <coord, coord> segment;

coord movement(ll move, int rotation) {
    // right & conterclockwise
    if (rotation == 0)
        return {{move, 0}, {0,0}};
    if (rotation == 315)
        return {{0, move}, {0,-move}};
    if (rotation == 270)
        return {{0, 0}, {-move,0}};
    if (rotation == 225)
        return {{0, -move}, {0,-move}};
    if (rotation == 180)
        return {{-move, 0}, {0,0}};
    if (rotation == 135)
        return {{0, -move}, {0,move}};
    if (rotation == 90)
        return {{0, 0}, {move,0}};
    if (rotation == 45)
        return {{0, move}, {0,move}};
    assert(false);
}

vector<vector<segment>> execute(int rotation, vector <pair<string, int>> &commands) {
    auto my_c = coord{{0, 0},
                      {0, 0}};
    vector<vector<segment>> unjoined(4);
    for (auto &c: commands) {
        if (c.first == "rotate") {
            rotation = (rotation + c.second) % 360;
        } else if (c.first == "move") {
            my_c += movement(c.second, rotation);
        } else {
            auto end = my_c + movement(c.second, rotation);
            unjoined[(rotation / 45) % 4].push_back({min(my_c, end), max(my_c, end)});
            my_c  =end;
        }
    }

    return unjoined;
}

vector <vector<segment>> join_segs(vector<vector<segment>> unjoined) {
    vector<vector<segment>> joined(4);

    for (int group = 0; group < 4; group++) {

        if (unjoined[group].empty())
            continue;

        map<dig, vector<segment>> onelined;
        for (auto i : unjoined[group]) {
            if (group == 0) { // x diff only, one line by y
                assert(i.first.second == i.second.second);
                onelined[i.first.second].push_back(i);
            }

            if (group == 3) { // one line by x + y
                assert(i.first.second + i.first.first == i.second.second + i.second.first);
                onelined[i.first.second + i.first.first].push_back(i);
            }

            if (group == 2) { // y diff only, one line by x
                assert(i.first.first == i.second.first);
                onelined[i.first.first].push_back(i);
            }

            if (group == 1) { // one line by x - y
                assert(i.first.second - i.first.first == i.second.second - i.second.first);
                onelined[i.first.second - i.first.first].push_back(i);
            }
        }

        for (auto &i : onelined) {
            auto v = i.second;
            sort(v.begin(), v.end());

            segment cur = v[0];
            int nxt = 1;
            while (nxt < v.size()) {
                // let's join cur with nxt if possible;
                // [         {      ]      }
                //         nxt.1  cur.2
                coord delta = cur.second - v[nxt].first;

                if (group == 1 || group == 3)
                    assert(delta.first.first == 0 && delta.second.first == 0);
                if (group == 2 || group == 0)
                    assert(delta.first.second == 0 && delta.second.second == 0);

                if (delta.first.first == 0 && delta.first.second == 0 && delta.second.first == 0 && delta.second.second == 0) {
                    cur.second = v[nxt].second;
                } else {
                    joined[group].push_back(cur);
                    cur = v[nxt];
                }
                nxt++;
            }
            joined[group].push_back(cur);
        }

        sort(joined[group].begin(), joined[group].end());
    }

    return joined;
}

void solve() {
    int n ;
    cin >> n;
    vector <pair<string, int>> commands(n);

    for (int i =0;i < n;i++ ){
        cin >> commands[i].first >> commands[i].second;
    }

    auto init = join_segs(execute(0, commands));

    for (int r = 45; r <= 360; r += 45) {
        auto other =  join_segs(execute(r % 360, commands));
        bool found = false;
        coord per;

        for (int g = 0; g < 4; g++) {
            if (!init[g].empty() && !other[g].empty()) {
                auto initial = init[g][0];
                auto should_be  = other[g][0];

                per = initial.first - should_be.first;
                found = true;
                break;
            }
        }

        if (!found)
            continue;

        for (int g = 0; g < 4; g++) {
            for (auto &i : other[g]) {
                i.first += per;
                i.second += per;
            }
        }

        if (other == init) {
            cout << r;
            return;
        }
    }
}

void test() {
    vector<pair<string, int>> v = {
            { "draw", 10 },
            {"rotate", 180},
            {"move", 5},
            {"rotate", 180},
            {"draw", 10}
    };
    vector<vector<segment>> was = {
            {
                {{{0, 0}, {0,0 }}, {{15, 0}, {0,0}}},
                {{{5, 0}, {0,1 }}, {{20, 0}, {0,1}}},
                {{{10, 0}, {0,0 }}, {{25, 0}, {0,0}}},
            },
            {},
            {},
            {
                    {{{10, 10}, {0,0 }}, {{20, 20}, {-10,-10}}},
                    {{{5, 0}, {0,1 }}, {{20, 0}, {0,1}}},
                    {{{10, 0}, {0,0 }}, {{25, 0}, {0,0}}},
            },
    };
    vector<vector<segment>> exp = {
            {
                    {{{0, 0}, {0,0 }}, {{25, 0}, {0,0}}},
                    {{{5, 0}, {0,1 }}, {{20, 0}, {0,1}}},
            },
            {},
            {},
            {},
    };

    auto act = join_segs(was);
    assert(exp == act);
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    cin.sync_with_stdio(false);
    cout.sync_with_stdio(false);
    int tt = 1;

#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
    cin >> tt;
#endif
    //test();

    while (tt--) {
        solve();
        cout << "\n";
    }
    return 0;
}
