#include <iostream>
#include <vector>
#include <string>
#include <stdint.h>
#include <map>
#include <set>
#include <algorithm>

using namespace std;


struct agg {
	int64_t off = 0;
	int64_t off_sqrt2 = 0;
	agg operator+(const agg& rhs) const {
		return agg{ off + rhs.off, off_sqrt2 + rhs.off_sqrt2 };
	}
	agg operator-(const agg& rhs) const {
		return agg{ off - rhs.off, off_sqrt2 - rhs.off_sqrt2 };
	}
	bool operator<(const agg& rhs) const {
		if (off == rhs.off) return off_sqrt2 < rhs.off_sqrt2;
		return off < rhs.off;
	}
	bool operator==(const agg& rhs) const {
		return off == rhs.off && off_sqrt2 == rhs.off_sqrt2;
	}
};

pair<int, int> dir[8] = {
	{0, -2},
	{-1, -1},
	{-2, 0},
	{-1, 1},
	{0, 2},
	{1, 1},
	{2, 0},
	{1, -1}
};

pair<agg, agg> get_agg(int64_t len, int d) {
	if (!dir[d].first || !dir[d].second) {
		return std::pair<agg, agg>{ agg{dir[d].first * len, 0}, agg{dir[d].second * len, 0} };
	}
	return std::pair<agg, agg>{ agg{ 0, dir[d].first * len }, agg{ 0, dir[d].second * len } };
}

struct state {
	agg x, y;
	agg to_x, to_y;
	int64_t len;
	int ang;
};

vector<state> st;

pair<agg, agg> rot45(pair<agg, agg> v) {
	return pair{ agg{v.first.off_sqrt2 - v.second.off_sqrt2, (v.first.off - v.second.off) / 2},
				agg{v.first.off_sqrt2 + v.second.off_sqrt2, (v.first.off + v.second.off) / 2} };
}

pair<agg, agg> rot(pair<agg, agg> v, int c) {
	while (c--) {
		v = rot45(v);
	}
	return v;
}

set<pair<pair<agg, agg>, pair<agg, agg>>> gen(int angle, agg x, agg y) {
	set<pair<pair<agg, agg>, pair<agg, agg>>> res;
	for (int i = 0; i < st.size(); ++i) {
		if (i) {
			pair<agg, agg> off{ st[i].x - st[i - 1].to_x, st[i].y - st[i - 1].to_y };
			off = rot(off, angle);
			x = x + off.first;
			y = y + off.second;
		}
		pair<agg, agg> beg = { x, y };
		pair<agg, agg> off{ st[i].to_x - st[i].x, st[i].to_y - st[i].y };
		off = rot(off, angle);
		x = x + off.first;
		y = y + off.second;
		pair<agg, agg> end{ x, y };
		res.emplace(min(beg, end), max(beg, end));
	}
	return res;
}


int main() {
	int n;
	cin >> n;
	map<int, vector<int>> by_len;
	int angle = 0;
	agg x{};
	agg y{};
	int i = 0;
	set<pair<pair<agg, agg>, pair<agg, agg>>> segs;
	for (; i < n; ++i) {
		string s;
		int c;
		cin >> s >> c;
		if (s == "rotate") {
			c /= 45;
			c &= 7;
			if ((angle += c) > 7) {
				angle -= 8;
			}
		}
		else if (s == "move") {
			continue;
		}
		else {
			st.emplace_back(state{ {}, {}, {}, {}, c, angle });
			by_len[c].emplace_back(st.size() - 1);
			auto [ox, oy] = get_agg(c, angle);
			x = x + ox;
			y = y + oy;
			st.back().to_x = x;
			st.back().to_y = y;
			break;
		}
	}
	++i;
	for (; i < n; ++i) {
		string s;
		int c;
		cin >> s >> c;
		if (s == "rotate") {

			c /= 45;
			c &= 7;
			if ((angle += c) > 7) {
				angle -= 8;
			}
		}
		else if (s == "move") {
			auto [ox, oy] = get_agg(c, angle);
			x = x + ox;
			y = y + oy;
		}
		else {
			st.emplace_back(state{ x, y, {}, {}, c, angle });
			by_len[c].emplace_back(st.size() - 1);
			auto [ox, oy] = get_agg(c, angle);
			x = x + ox;
			y = y + oy;
			st.back().to_x = x;
			st.back().to_y = y;
		}
	}
	for (auto& s : st) {
		pair beg{ s.x, s.y };
		pair end{ s.to_x, s.to_y };
		segs.emplace(min(beg, end), max(beg, end));
	}
	for (int angle = 1; angle <= 7; ++angle) {
		for (auto& id : by_len[st[0].len]) {
			if (gen(angle & 7, st[id].x, st[id].y) == segs) {
				cout << angle * 45 << "\n";
				return 0;
			}
			if (gen(angle & 7, st[id].to_x, st[id].to_y) == segs) {
				cout << angle * 45 << "\n";
				return 0;
			}
		}
	}
	cout << "360\n";
}